/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.wso2.registry.ui.actions;

import org.wso2.registry.Artifact;
import org.wso2.registry.RegistryException;
import org.wso2.registry.Registry;
import org.wso2.registry.RegistryConstants;

import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

import com.opensymphony.xwork2.ActionSupport;


public class SearchAction extends AbstractRegistryAction {

    private String searchString;
    private String includetags;
    private String includetitles;
    private String includedescriptions;
    private List resourceDataList = new ArrayList();

    private String[] paths;

    private void appendPaths(List paths, String[] results) {

        for (int i = 0; i < results.length; i++) {

            if (!paths.contains(results[i])) {
                paths.add(results[i]);
            }
        }
    }

    public String execute() throws Exception {

        Registry registry = getRegistry();
            Artifact result;
        try {

            List pathList = new ArrayList();

            if(includedescriptions.equals("on")){
             result = registry.executeQuery("/qs/searchDescription", new String[]{"%" + searchString + "%"});
             paths = (String[]) result.getContent();
                appendPaths(pathList, paths);
            }

            if(includetags.equals("on")){
             result = registry.executeQuery("/qs/searchTag", new String[]{"%" + searchString + "%"});
             paths = (String[]) result.getContent();
                appendPaths(pathList, paths);
            }



            Artifact artifact;
            Iterator i = pathList.iterator();

            while(i.hasNext()) {
                String resultPath = (String) i.next();
                ResourceData resourceData = new ResourceData();
                resourceData.setPath(resultPath);
                artifact = registry.get(resultPath);

                String[] parts = resultPath.split(RegistryConstants.PATH_SEPARATOR);

                resourceData.setName(parts[parts.length - 1]);
                resourceData.setAuthorUserName(artifact.getAuthorUserName());
                resourceData.setDescription(artifact.getDescription());
                resourceData.setRating(registry.getAverageRating(resultPath));
                resourceDataList.add(resourceData);

            }


        } catch (
                RegistryException e) {
            //     fail("Failed to execute query.");
        }

        return ActionSupport.SUCCESS;
    }

    public String getSearchString() {
        return searchString;
    }

    public void setSearchString(String searchString) {
        this.searchString = searchString;
    }

    public String getIncludetitles() {
        return includetitles;
    }

    public void setIncludetitles(String includetitles) {
        this.includetitles = includetitles;
    }

    public String getIncludedescriptions() {
        return includedescriptions;
    }

    public void setIncludedescriptions(String includedescriptions) {
        this.includedescriptions = includedescriptions;
    }

    public String getIncludetags() {
        return includetags;
    }

    public void setIncludetags(String includetags) {
        this.includetags = includetags;
    }

    public List getResourceDataList() {
        return resourceDataList;
    }

    public void setResourceDataList(List resourceDataList) {
        this.resourceDataList = resourceDataList;
    }

}
